@@ -139,7 +139,7 @@ class _StructureGraph(BaseFeature):
             raise NotImplementedError()
 
         atoms = self.get_atom_fea(structure)
-        atoms = [atoms[int(i)] for i in center_indices]
+        atoms = [atoms[round(i)] for i in center_indices]
         atoms = self.atom_converter.convert(atoms)
         bonds = self.bond_converter.convert(bondss)
 
@@ -303,7 +303,7 @@ class CrystalGraph(_StructureGraphFixedRadius):
 
     def __init__(
             self,
-            nn_strategy: Union[str, NearNeighbors] = "MinimumDistanceNNAll",
+            nn_strategy: Union[str, NearNeighbors] = "find_points_in_spheres",
             atom_converter: Converter = None,
             bond_converter: Converter = None,
             state_converter: Converter = None,
